@@ -5,6 +5,7 @@ import hmac
 import json
 from .compat import urlparse
 from hashlib import sha1
+from util import urlsafe_base64_encode, urlsafe_base64_decode
 import time
 
 class Auth(object):
@@ -32,10 +33,12 @@ class Auth(object):
         #    raise ValueError("Invalid deadline")
 
         jsonputPolicy = json.dumps(putPolicy)
-        encodePutPolicy = base64.b64encode(jsonputPolicy)
+        #encodePutPolicy = base64.b64encode(jsonputPolicy)
+        encodePutPolicy = urlsafe_base64_encode(jsonputPolicy)
         tmp_encodePutPolicy = encodePutPolicy
         Sign = hmac.new(self.secret_key, bytes(encodePutPolicy), sha1)    
-        encodeSign = base64.b64encode(Sign.hexdigest())
+        #encodeSign = base64.b64encode(Sign.hexdigest())
+        encodeSign = urlsafe_base64_encode(Sign.hexdigest())
         return '{0}:{1}:{2}'.format(self.access_key, encodeSign, tmp_encodePutPolicy)
 
     def managertoken(self, url, body=None):
