@@ -2,7 +2,6 @@ import base64
 import json
 from wcs.commons.auth import Auth
 from wcs.commons.config import MGR_URL
-from wcs.commons.config import GET_URL
 from wcs.commons.config import logging_folder
 from wcs.commons.http import _post
 from wcs.commons.http import _get
@@ -14,7 +13,6 @@ class BucketManager(object):
     def __init__(self, auth):
         self.auth = auth
         self.mgr_host = MGR_URL
-        self.get_host = GET_URL
         self.logger = get_logger(logging_folder, 'FileManager')
 
     def limit_check(self):
@@ -29,7 +27,7 @@ class BucketManager(object):
         return headers
     
     def make_delete_url(self, bucket, key):
-        return 'http://{0}/delete/{1}'.format(self.mgr_host, entry(bucket, key))
+        return '{0}/delete/{1}'.format(self.mgr_host, entry(bucket, key))
 
     def delete(self, bucket, key):
         url = self.make_delete_url(bucket, key)
@@ -39,7 +37,7 @@ class BucketManager(object):
         return code, text
 
     def make_filestat_url(self, bucket, key):
-        return 'http://{0}/stat/{1}'.format(self.mgr_host, entry(bucket, key))
+        return '{0}/stat/{1}'.format(self.mgr_host, entry(bucket, key))
 
     def stat(self, bucket, key):
         url = self.make_filestat_url(bucket, key)
@@ -49,7 +47,7 @@ class BucketManager(object):
         return code, text
  
     def make_list_url(self, param):
-        url = ['http://{0}/list'.format(self.mgr_host)]
+        url = ['{0}/list'.format(self.mgr_host)]
         if param:
             url.append(self.params_parse(param))
         url = '?'.join(url)
@@ -90,7 +88,7 @@ class BucketManager(object):
     def make_move_url(self, srcbucket, srckey, dstbucket, dstkey):
         src = base64.b64encode('%s:%s' % (srcbucket, srckey))
         dst = base64.b64encode('%s:%s' % (dstbucket, dstkey)) 
-        url = 'http://{0}/move/{1}/{2}'.format(self.mgr_host, src, dst)
+        url = '{0}/move/{1}/{2}'.format(self.mgr_host, src, dst)
         return url
 
     def move(self, srcbucket, srckey, dstbucket, dstkey):
@@ -103,7 +101,7 @@ class BucketManager(object):
     def make_copy_url(self, srcbucket, srckey, dstbucket, dstkey):
         src = base64.b64encode('%s:%s' % (srcbucket, srckey))
         dst = base64.b64encode('%s:%s' % (dstbucket, dstkey))
-        url = 'http://{0}/copy/{1}/{2}'.format(self.mgr_host, src, dst)
+        url = '{0}/copy/{1}/{2}'.format(self.mgr_host, src, dst)
         return url
 
     def copy(self, srcbucket, srckey, dstbucket, dstkey):
@@ -114,7 +112,7 @@ class BucketManager(object):
         return code, text
 
     def setdeadline(self, bucket, key, deadline):
-        url = 'http://{0}/setdeadline'.format(self.mgr_host)
+        url = '{0}/setdeadline'.format(self.mgr_host)
         param = {
             'bucket' : base64.b64encode(bucket),
         }
@@ -127,7 +125,7 @@ class BucketManager(object):
         return code, text
 
 #    def decompress(self, bucket, key, fops, notifyurl=None, force=None, separate=None):
-#        url = 'http://{0}/fops'.format(self.mgr_host)
+#        url = '{0}/fops'.format(self.mgr_host)
 #        data = {'fops': fops}
 #        if notifyurl is not None:
 #            data['notifyURL'] = base64.b64encode(notifyurl) 
@@ -148,7 +146,7 @@ class BucketManager(object):
 #                encodelist.append(base64.b64encode(key))
 #            encodelist = '|'.join(encodelist)
 #        param = base64.b64encode('{0}:{1}'.format(bucket, encodelist))
-#        url = 'http://{0}/prefetch/{1}'.format(self.mgr_host, param)
+#        url = '{0}/prefetch/{1}'.format(self.mgr_host, param)
 #        self.logger.info('Update mirror to bucket: %s' % (bucket))
 #        code, text = _post(url=url, headers=self.gernerate_headers(url))
 #        self.logger.info('The return code : %d and text : %s', code, text)
