@@ -38,7 +38,7 @@ class PersistentFop(object):
         return ops_list
 
     def fops_status(self, persistentId):
-        url = 'http://{0}/status/get/prefop?persistentId={1}'.format(self.host, persistentId)
+        url = '{0}/status/get/prefop?persistentId={1}'.format(self.host, persistentId)
         self.logger.info('Start to get status of persistentId: %s', persistentId)
         code, text = _get(url=url)
         self.logger.info('The return code and text of status request is:%d %s', code, text)
@@ -66,7 +66,7 @@ class PersistentFop(object):
             data['force'] = 1
         if separate == 1:
             data['separate'] = 1
-        url = 'http://{0}/fops'.format(self.host)
+        url = '{0}/fops'.format(self.host)
         headers,reqdata = self.headers(url,data)
         self.logger.info('PersistentFops is %s', fops)
         self.logger.info('Start to post persistentFops')
