@@ -5,6 +5,7 @@ import sys
 from wcs.commons.config import PUT_URL
 from wcs.commons.http import _post
 from wcs.commons.util import get_logger
+from wcs.commons.util import urlsafe_base64_decode
 from wcs.commons.config import logging_folder
 from poster.encode import multipart_encode
 
@@ -36,7 +37,7 @@ class RegUpload(object):
         self.logger = get_logger(logging_folder, 'regupload')
         
     def reg_upload(self, filepath):
-        puturl = "http://{0}/{1}/{2}".format(PUT_URL,"file","upload")
+        puturl = "{0}/{1}/{2}".format(PUT_URL,"file","upload")
         if os.path.exists(filepath) and os.path.isfile(filepath):
             filedir,filename = os.path.split(filepath)
             self.fileds['file'] = open(filepath, 'rb')
@@ -52,4 +53,9 @@ class RegUpload(object):
             self.logger.error('There is exception:%s in upload progress', e)
             return -1, e
         self.logger.info('The result of upload is: %d, %s', r.status_code, r.text)
+        # user need to decode text by itself, for text may be json,for example in callback upload
+        #if r.status_code == 200:
+        #    return r.status_code, urlsafe_base64_decode(r.text)
+        #else:
+        #    return r.status_code, r.text
         return r.status_code, r.text
