@@ -165,7 +165,7 @@ class SliceUpload(object):
         return _post(url=url, headers=headers, data=bput_next)
         
     def bput_url(self, ctx, offset):
-        return 'http://{0}/bput/{1}/{2}'.format(PUT_URL, ctx, offset)
+        return '{0}/bput/{1}/{2}'.format(PUT_URL, ctx, offset)
     
     def bput_headers(self, uploadBatch):
         headers = {'Authorization':self.uploadtoken }
@@ -220,7 +220,7 @@ class SliceUpload(object):
         return offset, bputcode, bputtext['ctx']
       
     def block_url(self, size, blocknum):
-        return 'http://{0}/mkblk/{1}/{2}'.format(PUT_URL, size, blocknum)
+        return '{0}/mkblk/{1}/{2}'.format(PUT_URL, size, blocknum)
 
     def block_headers(self,uploadBatch):
         headers = {'Authorization':self.uploadtoken}
@@ -229,7 +229,7 @@ class SliceUpload(object):
         return headers
 
     def file_url(self, host):
-        url = ['http://{0}/mkfile/{1}'.format(host, self.size)]
+        url = ['{0}/mkfile/{1}'.format(host, self.size)]
         if self.params:
             for k, v in self.params.items():
                 url.append('x:{0}/{1}'.format(k, base64.b64encode(v)))
@@ -260,4 +260,4 @@ class SliceUpload(object):
            self.upload_progress_recorder.delete_upload_record(self.key)
         else:
            self.logger.info('Make_file suc! sliceupload complet!')
-        return code,text
+        return code, text
